@@ -1,38 +1,44 @@
-use std::{io, ptr, mem, ffi, slice};
-use libc::{c_void, c_int, size_t, sysctl, sysctlnametomib, timeval, statfs};
-use crate::data::*;
 use super::common::*;
 use super::unix;
+use crate::data::*;
+use libc::{c_int, c_void, size_t, statfs, sysctl, sysctlnametomib, timeval};
+use std::{ffi, io, mem, ptr, slice};
 
 pub struct PlatformImpl;
 
 macro_rules! sysctl_mib {
-    ($len:expr, $name:expr) => {
-        {
-            let mut mib: [c_int; $len] = [0; $len];
-            let mut sz: size_t = mib.len();
-            let s = ffi::CString::new($name).unwrap();
-            unsafe { sysctlnametomib(s.as_ptr(), &mut mib[0], &mut sz) };
-            mib
-        }
-    }
+    ($len:expr, $name:expr) => {{
+        let mut mib: [c_int; $len] = [0; $len];
+        let mut sz: size_t = mib.len();
+        let s = ffi::CString::new($name).unwrap();
+        unsafe { sysctlnametomib(s.as_ptr(), &mut mib[0], &mut sz) };
+        mib
+    }};
 }
 
 macro_rules! sysctl {
-    ($mib:expr, $dataptr:expr, $size:expr, $shouldcheck:expr) => {
+    ($mib:expr, $dataptr:expr, $size:expr, $shouldcheck:expr) => {{
+        let mib = &$mib;
+        let mut size = $size;
+        if unsafe {
+            sysctl(
+                &mib[0] as *const _ as *mut _,
+                mib.len() as u32,
+                $dataptr as *mut _ as *mut c_void,
+                &mut size,
+                ptr::null_mut(),
+                0,
+            )
+        } != 0
+            && $shouldcheck
         {
-            let mib = &$mib;
-            let mut size = $size;
-            if unsafe { sysctl(&mib[0] as *const _ as *mut _, mib.len() as u32,
-                               $dataptr as *mut _ as *mut c_void, &mut size, ptr::null_mut(), 0) } != 0 && $shouldcheck {
-                return Err(io::Error::new(io::ErrorKind::Other, "sysctl() failed"))
-            }
-            size
+            return Err(io::Error::new(io::ErrorKind::Other, "sysctl() failed"));
         }
-    };
+        size
+    }};
     ($mib:expr, $dataptr:expr, $size:expr) => {
         sysctl!($mib, $dataptr, $size, true)
-    }
+    };
 }
 
 lazy_static! {
@@ -62,7 +68,10 @@ impl Platform for PlatformImpl {
     fn boot_time(&self) -> io::Result<DateTime<Utc>> {
         let mut data: timeval = unsafe { mem::zeroed() };
         sysctl!(KERN_BOOTTIME, &mut data, mem::size_of::<timeval>());
-        Ok(DateTime::<Utc>::from_utc(NaiveDateTime::from_timestamp(data.tv_sec.into(), data.tv_usec as u32), Utc))
+        Ok(DateTime::<Utc>::from_utc(
+            NaiveDateTime::from_timestamp(data.tv_sec.into(), data.tv_usec as u32),
+            Utc,
+        ))
     }
 
     fn battery_life(&self) -> io::Result<BatteryLife> {
@@ -77,7 +86,7 @@ impl Platform for PlatformImpl {
         let mut mptr: *mut statfs = ptr::null_mut();
         let len = unsafe { getmntinfo(&mut mptr, 2 as i32) };
         if len < 1 {
-            return Err(io::Error::new(io::ErrorKind::Other, "getmntinfo() failed"))
+            return Err(io::Error::new(io::ErrorKind::Other, "getmntinfo() failed"));
         }
         let mounts = unsafe { slice::from_raw_parts(mptr, len as usize) };
         Ok(mounts.iter().map(statfs_to_fs).collect::<Vec<_>>())
@@ -109,13 +118,25 @@ fn statfs_to_fs(x: &statfs) -> Filesystem {
         files: (x.f_files as usize).saturating_sub(x.f_ffree as usize),
         files_total: x.f_files as usize,
         files_avail: x.f_ffree as usize,
-        free: ByteSize::b(x.f_bfree * x.f_bsize as u64),
-        avail: ByteSize::b(x.f_bavail * x.f_bsize as u64),
-        total: ByteSize::b(x.f_blocks * x.f_bsize as u64),
+        free: readable_byte::b(x.f_bfree * x.f_bsize as u64),
+        avail: readable_byte::b(x.f_bavail * x.f_bsize as u64),
+        total: readable_byte::b(x.f_blocks * x.f_bsize as u64),
         name_max: 256,
-        fs_type: unsafe { ffi::CStr::from_ptr(&x.f_fstypename[0]).to_string_lossy().into_owned() },
-        fs_mounted_from: unsafe { ffi::CStr::from_ptr(&x.f_mntfromname[0]).to_string_lossy().into_owned() },
-        fs_mounted_on: unsafe { ffi::CStr::from_ptr(&x.f_mntonname[0]).to_string_lossy().into_owned() },
+        fs_type: unsafe {
+            ffi::CStr::from_ptr(&x.f_fstypename[0])
+                .to_string_lossy()
+                .into_owned()
+        },
+        fs_mounted_from: unsafe {
+            ffi::CStr::from_ptr(&x.f_mntfromname[0])
+                .to_string_lossy()
+                .into_owned()
+        },
+        fs_mounted_on: unsafe {
+            ffi::CStr::from_ptr(&x.f_mntonname[0])
+                .to_string_lossy()
+                .into_owned()
+        },
     }
 }
 
